==> SoG-paper-0.12.tar.gz: SoG-paper-0.12/setup.py <==
#!/usr/bin/python

#
# Project Librarian: Brandon Piotrzkowski
#              Research Associate
#              UW-Milwaukee Department of Physics
#              Center for Gravitation & Cosmology
#              <alexander.urban@ligo.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#


from setuptools import setup, find_packages


setup(
    name='SoG-paper',
    version='0.12',
    url='https://git.ligo.org/olivier.minazzoli/sog_liv_manuscript_template',
    author='Brandon Piotrzkowski',
    author_email='brandon.piotrzkowski@ligo.org',
    description='Low-latency manuscript of speed of gravity measurement',
    license='GNU General Public License Version 3',
    classifiers=(
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "Topic :: Internet",
        "Topic :: Scientific/Engineering :: Astronomy",
        "Topic :: Scientific/Engineering :: Physics"
    ),
    packages=find_packages(),
    include_package_data=True,
    package_data={'': ['tex/files/*']},
    namespace_packages=['SoG'],
    scripts=[
        'bin/SoG_generate_pdf',
        'bin/SoG_upload_pdf',
    ],
    install_requires=[
        'numpy>=1.14.5',
        'healpy!=1.12.0',   # FIXME: https://github.com/healpy/healpy/pull/457
        'gracedb-sdk',
        'matplotlib',
        'astropy',
        'scipy>=0.7.2',
        'ligo.skymap>=0.1.1',
        'lxml',
        'ligo-raven',
        'tqdm'
    ],
    python_requires='>=3.8',
)

==> SoG-paper-0.13.tar.gz: SoG-paper-0.13/setup.py <==
#!/usr/bin/python

#
# Project Librarian: Brandon Piotrzkowski
#              Research Associate
#              UW-Milwaukee Department of Physics
#              Center for Gravitation & Cosmology
#              <alexander.urban@ligo.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#


from setuptools import setup, find_packages


setup(
    name='SoG-paper',
    version='0.13',
    url='https://git.ligo.org/olivier.minazzoli/sog_liv_manuscript_template',
    author='Brandon Piotrzkowski',
    author_email='brandon.piotrzkowski@ligo.org',
    description='Low-latency manuscript of speed of gravity measurement',
    license='GNU General Public License Version 3',
    classifiers=(
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "Topic :: Internet",
        "Topic :: Scientific/Engineering :: Astronomy",
        "Topic :: Scientific/Engineering :: Physics"
    ),
    packages=find_packages(),
    include_package_data=True,
    package_data={'': ['tex/files/*']},
    namespace_packages=['SoG'],
    scripts=[
        'bin/SoG_generate_pdf'
    ],
    install_requires=[
        'numpy>=1.14.5',
        'healpy!=1.12.0',   # FIXME: https://github.com/healpy/healpy/pull/457
        'gracedb-sdk',
        'matplotlib',
        'astropy',
        'scipy>=0.7.2',
        'ligo.skymap>=0.1.1',
        'lxml',
        'ligo-raven',
        'tqdm'
    ],
    python_requires='>=3.8',
)
